@@ -19,7 +19,7 @@ from time import time, sleep, localtime, strftime
 import logging
 import xarray as xr
 from datetime import datetime
-from labphew.core.base import OperatorBase
+from labphew.core.base.operator_base import OperatorBase
 import labphew
 
 
